'use client'

import React, { useState, useEffect, useRef } from 'react'
import { motion, useAnimation, AnimatePresence } from 'framer-motion'

interface TestimonialProps {
  quote: string
  author: string
  source: string
}

const testimonials: TestimonialProps[] = [
  {
    quote: "Intuitive design happens when current knowledge is the same as the target knowledge.",
    author: "Jared Spool",
    source: "Web Site Usability: A Designer's Guide"
  },
  {
    quote: "Good design is actually a lot harder to notice than poor design, in part because good designs fit our needs so well that the design is invisible.",
    author: "Don Norman",
    source: "The Design of Everyday Things"
  },
  {
    quote: "A user interface is like a joke. If you have to explain it, it's not that good.",
    author: "Martin LeBlanc",
    source: "Iconfinder"
  }
]

const TestimonialSection2: React.FC = () => {
  const [currentIndex, setCurrentIndex] = useState(0)
  const controls = useAnimation()
  const ref = useRef<HTMLDivElement>(null)
  const [inView, setInView] = useState(false)

  useEffect(() => {
    const observer = new IntersectionObserver(
      ([entry]) => {
        setInView(entry.isIntersecting)
      },
      {
        threshold: 0.1
      }
    )

    if (ref.current) {
      observer.observe(ref.current)
    }

    return () => {
      if (ref.current) {
        observer.unobserve(ref.current)
      }
    }
  }, [])

  useEffect(() => {
    if (inView) {
      controls.start('visible')
    }
  }, [controls, inView])

  useEffect(() => {
    const timer = setInterval(() => {
      handleNext()
    }, 5000) // Change testimonial every 5 seconds

    return () => clearInterval(timer)
  }, [currentIndex])

  const containerVariants = {
    hidden: { opacity: 0, y: 50 },
    visible: {
      opacity: 1,
      y: 0,
      transition: {
        duration: 0.5
      }
    }
  }

  const slideVariants = {
    enter: { opacity: 0, x: 50 },
    center: { opacity: 1, x: 0 },
    exit: { opacity: 0, x: -50 }
  }

  const highlightWords = (text: string) => {
    return text.split(' ').map((word, index) => {
      const shouldHighlight = ['current', 'knowledge', 'target'].includes(word.toLowerCase())
      return (
        <span key={index} style={{ color: shouldHighlight ? '#ffffff' : 'inherit' }}>
          {word}{' '}
        </span>
      )
    })
  }

  const handlePrev = () => {
    setCurrentIndex((prevIndex) => (prevIndex - 1 + testimonials.length) % testimonials.length)
  }

  const handleNext = () => {
    setCurrentIndex((prevIndex) => (prevIndex + 1) % testimonials.length)
  }

  return (
    <section ref={ref} className="unique-blockquote-section">
      <div className="unique-blockquote-wrapper">
        <motion.div
          className="unique-blockquote"
          variants={containerVariants}
          initial="hidden"
          animate={controls}
        >
          <AnimatePresence mode="wait">
            <motion.div
              key={currentIndex}
              variants={slideVariants}
              initial="enter"
              animate="center"
              exit="exit"
              transition={{ duration: 0.5 }}
            >
              <h1>{highlightWords(testimonials[currentIndex].quote)}</h1>
              <h4>
                —{testimonials[currentIndex].author}
                <br />
                <em>{testimonials[currentIndex].source}</em>
              </h4>
            </motion.div>
          </AnimatePresence>
          <div className="unique-blockquote-nav">
            <button className="unique-blockquote-nav-btn prev" onClick={handlePrev}>
              &#8592;
            </button>
            <button className="unique-blockquote-nav-btn next" onClick={handleNext}>
              &#8594;
            </button>
          </div>
        </motion.div>
      </div>
    </section>
  )
}

export default TestimonialSection2